Watson-Form
===========

Make working with HTML forms more tolerable.

For full documentation please see `Read The
Docs <http://watson-form.readthedocs.org/>`__.

Build Status
^^^^^^^^^^^^

|Build Status| |Coverage Status| |Version| |Downloads| |Licence|

Installation
------------

``pip install watson-form``

Dependencies
------------

-  watson-common
-  watson-html
-  watson-validators
-  watson-filters

Optional
~~~~~~~~

-  watson-http

.. |Build Status| image:: https://api.travis-ci.org/watsonpy/watson-form.png?branch=master
   :target: https://travis-ci.org/watsonpy/watson-form
.. |Coverage Status| image:: https://coveralls.io/repos/watsonpy/watson-form/badge.png
   :target: https://coveralls.io/r/watsonpy/watson-form
.. |Version| image:: http://badge.kloud51.com/pypi/v/watson-form.png
   :target: https://pypi.python.org/pypi/watson-form/
.. |Downloads| image:: http://badge.kloud51.com/pypi/d/watson-form.png
   :target: https://pypi.python.org/pypi/watson-form/
.. |Licence| image:: http://badge.kloud51.com/pypi/license/watson-form.png
   :target: https://pypi.python.org/pypi/watson-form/
